@@ -13,15 +13,16 @@ NULL
 #' 
 #' @param x an object with simulated residuals created by \code{\link{simulateResiduals}}
 #' @param ... optional arguments to pass on to \code{\link{plotSimulatedResiduals}}
+#' @details The function calls \code{\link{plotSimulatedResiduals}} - see details there
 #' @export
 plot.DHARMa <- function(x, ...){
-  plotSimulatedResiduals(x, ...)
+  plotSimulatedResiduals(simulationOutput = x, ...)
 }
 
 #' Print simulated residuals
 #' 
 #' @param x an object with simulated residuals created by \code{\link{simulateResiduals}}
-#' @param ... optional arguments to pass on to \code{\link{plotSimulatedResiduals}}
+#' @param ... optional arguments for compatibility with genetic, no function implemented
 #' @export
 print.DHARMa <- function(x, ...){
   cat(paste("Object of Class DHARMa with simulated residuals based on", x$nSim, "simulations with refit =", x$refit , ". See ?DHARMa::simulateResiduals for help."), "\n", "\n")
@@ -32,7 +33,7 @@ print.DHARMa <- function(x, ...){
 } 
 
 
-#' Convert simulated residuals to a DHARMa object
+#' Convert simulated residuals or posterior predictive simulations to a DHARMa object
 #' 
 #' @param scaledResiduals optional scaled residuals from a simulation, e.g. Bayesian p-values. If those are not provided, simulated and true observations have to be provided. 
 #' @param simulatedResponse matrix of observations simulated from the fitted model - row index for observations and colum index for simulations 
@@ -41,10 +42,13 @@ print.DHARMa <- function(x, ...){
 #' @param integerResponse if T, noise will be added at to the residuals to maintain a uniform expectations for integer responses (such as Poisson or Binomial). Unlike in \code{\link{simulateResiduals}}, the nature of the data is not automatically detected, so this MUST be set by the user appropriately
 #' @details The use of this function is to convert simulated residuals (e.g. from a point estimate, or Bayesian p-values) to a DHARMa object, to make use of the plotting / test functions in DHARMa 
 #' @note Either scaled residuals or (simulatedResponse AND observed response) have to be provided 
+#' @example inst/examples/createDharmaHelp.R
 #' @export
 createDHARMa <- function(scaledResiduals = NULL, simulatedResponse = NULL, observedResponse = NULL, fittedPredictedResponse = NULL, integerResponse = F){
   out = list()
 
+  if(is.matrix(scaledResiduals) | is.data.frame(scaledResiduals)) stop("DHARMa::createDHARMa - matrix provided to parmaeter scaledResiduals - if you want to provide simulations, use parameter simulatedResponse")
+  
   if(is.null(scaledResiduals)) {
     if(!is.matrix(simulatedResponse) & !is.null(observedResponse)) stop("either scaled residuals or simulations and observations have to be provided")
     
